# Example Package
#在此文件内，可使用markdown撰写对包的详细介绍和说明，便于别人熟悉和使用，在此不再赘述
This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.
python setup.py sdist bdist_wheel  
python -m twine upload dist/*

python -m twine upload --repository testpypi dist/*